diff lisp/mule/cyrillic.el @ 444:576fb035e263 r21-2-37

Import from CVS: tag r21-2-37
author cvs
date Mon, 13 Aug 2007 11:36:19 +0200
parents 3ecd8885ac67
children 943eaba38521
line wrap: on
line diff
--- a/lisp/mule/cyrillic.el	Mon Aug 13 11:35:05 2007 +0200
+++ b/lisp/mule/cyrillic.el	Mon Aug 13 11:36:19 2007 +0200
@@ -25,12 +25,13 @@
 
 ;;; Commentary:
 
 ;; The character set ISO8859-5 is supported.  KOI-8 and ALTERNATIVNYJ
 ;; are converted to ISO8859-5 internally.
 
 ;;; Code:
 
-;; For syntax of Cyrillic
+;; Cyrillic syntax
 (modify-syntax-entry 'cyrillic-iso8859-5 "w")
 (modify-syntax-entry ?,L-(B ".")
 (modify-syntax-entry ?,Lp(B ".")
@@ -40,21 +41,11 @@
 ;;; CYRILLIC
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;; ISO-8859-5 staff
-
-;; (make-coding-system
-;;  'cyrillic-iso-8bit 2 ?5
-;;  "ISO 2022 based 8-bit encoding for Cyrillic script (MIME:ISO-8859-5)"
-;;  '(ascii cyrillic-iso8859-5  nil nil
-;;    nil nil nil nil nil nil nil)
-;;  '((safe-charsets ascii cyrillic-iso8859-5)
-;;    (mime-charset . iso-8859-5)))
-
-;; (define-coding-system-alias 'iso-8859-5 'cyrillic-iso-8bit)
+;; ISO-8859-5
 
 (make-coding-system
  'iso-8859-5 'iso2022
- "MIME ISO-8859-5"
+ "ISO-8859-5 (ISO 2022 based 8-bit encoding for Cyrillic script)"
  '(charset-g0 ascii
    charset-g1 cyrillic-iso8859-5
    charset-g2 t
@@ -73,7 +64,7 @@
 		  (documentation . "Support for Cyrillic ISO-8859-5."))
  '("Cyrillic"))
 
-;; KOI-8 staff
+;; KOI-8
 
 (eval-and-compile
 
@@ -133,31 +124,17 @@
 	 (write-read-repeat r0 , cyrillic-koi8-r-encode-table))))))
   "CCL program to encode KOI8.")
 
-;; (make-coding-system
-;;  'cyrillic-koi8 4
-;;  ;; We used to use ?K.  It is true that ?K is more strictly correct,
-;;  ;; but it is also used for Korean.
-;;  ;; So people who use koi8 for languages other than Russian
-;;  ;; will have to forgive us.
-;;  ?R "KOI8 8-bit encoding for Cyrillic (MIME: KOI8-R)"
-;;  '(ccl-decode-koi8 . ccl-encode-koi8)
-;;  '((safe-charsets ascii cyrillic-iso8859-5)
-;;    (mime-charset . koi8-r)
-;;    (valid-codes (0 . 127) 163 179 (192 . 255))
-;;    (charset-origin-alist (cyrillic-iso8859-5 "KOI8-R"
-;;                                              cyrillic-encode-koi8-r-char))))
-
 ;; (define-coding-system-alias 'koi8-r 'cyrillic-koi8)
 ;; (define-coding-system-alias 'koi8 'cyrillic-koi8)
 
 (make-coding-system
  'koi8-r 'ccl
- "Coding-system used for KOI8-R."
- `(decode ,ccl-decode-koi8
-   encode ,ccl-encode-koi8
+ "KOI8-R 8-bit encoding for Cyrillic."
+ '(decode ccl-decode-koi8
+   encode ccl-encode-koi8
    mnemonic "KOI8"))
 
-;; it is not correct, but XEmacs doesn't have `ccl' category...
+;; `iso-8-1' is not correct, but XEmacs doesn't have a `ccl' category
 (coding-system-put 'koi8-r 'category 'iso-8-1)
 
 ;; (define-ccl-program ccl-encode-koi8-font
@@ -184,7 +161,88 @@
 		   (documentation . "Support for Cyrillic KOI8-R."))
  '("Cyrillic"))
 
-;;; ALTERNATIVNYJ staff
+;;; WINDOWS-1251
+
+(eval-and-compile
+
+(defvar cyrillic-windows-1251-decode-table
+  [
+   0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15
+   16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31
+   32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47
+   48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63
+   64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79
+   80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95
+   96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111
+   112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127
+   ?,L"(B ?,L#(B 32 ?,Ls(B 32 32 32 32 32 32 ?,L)(B 32 ?,L*(B ?,L,(B ?,L+(B ?,L/(B ;"
+   ?,Lr(B 32 32 32 32 32 32 32 32 32 ?,Ly(B 32 ?,Lz(B ?,L|(B ?,L{(B ?,L(B
+   ?,L (B ?,L.(B ?,L~(B ?,L((B ?,A$(B 32 ?,A&(B ?,L}(B ?,L!(B ?,A)(B ?,L$(B ?,A+(B ?,A,(B ?,L-(B ?,A.(B ?,L'(B
+   ?,A0(B ?,A1(B ?,L&(B ?,Lv(B 32 ?,A5(B ?,A6(B ?,A7(B ?,Lq(B ?,Lp(B ?,Lt(B ?,A;(B ?,Lx(B ?,L%(B ?,Lu(B ?,Lw(B
+  ?,L0(B ?,L1(B ?,L2(B ?,L3(B ?,L4(B ?,L5(B ?,L6(B ?,L7(B ?,L8(B ?,L9(B ?,L:(B ?,L;(B ?,L<(B ?,L=(B ?,L>(B ?,L?(B
+  ?,L@(B ?,LA(B ?,LB(B ?,LC(B ?,LD(B ?,LE(B ?,LF(B ?,LG(B ?,LH(B ?,LI(B ?,LJ(B ?,LK(B ?,LL(B ?,LM(B ?,LN(B ?,LO(B
+  ?,LP(B ?,LQ(B ?,LR(B ?,LS(B ?,LT(B ?,LU(B ?,LV(B ?,LW(B ?,LX(B ?,LY(B ?,LZ(B ?,L[(B ?,L\(B ?,L](B ?,L^(B ?,L_(B
+  ?,L`(B ?,La(B ?,Lb(B ?,Lc(B ?,Ld(B ?,Le(B ?,Lf(B ?,Lg(B ?,Lh(B ?,Li(B ?,Lj(B ?,Lk(B ?,Ll(B ?,Lm(B ?,Ln(B ?,Lo(B ]
+   "Cyrillic Windows-1251 decoding table.")
+
+(defvar cyrillic-windows-1251-encode-table
+  (let ((table (make-vector 256 32))
+	(i 0))
+    (while (< i 256)
+      (let* ((ch (aref cyrillic-windows-1251-decode-table i))
+	     (split (split-char ch)))
+	(cond ((eq (car split) 'cyrillic-iso8859-5)
+	       (aset table (logior (nth 1 split) 128) i)
+	       )
+	      ((eq ch 32))
+	      ((eq (car split) 'ascii)
+	       (aset table ch i)
+	       )))
+      (setq i (1+ i)))
+    table)
+  "Cyrillic Windows-1251 encoding table.")
+
+)
+
+(define-ccl-program ccl-decode-windows1251
+  `(3
+    ((read r0)
+     (loop
+      (write-read-repeat r0 ,cyrillic-windows-1251-decode-table))))
+  "CCL program to decode Windows-1251.")
+
+(define-ccl-program ccl-encode-windows1251
+  `(1
+    ((read r0)
+     (loop
+      (if (r0 != ,(charset-id 'cyrillic-iso8859-5))
+	  (write-read-repeat r0)
+	((read r0)
+	 (write-read-repeat r0 , cyrillic-windows-1251-encode-table))))))
+  "CCL program to encode Windows-1251.")
+
+(make-coding-system
+ 'windows-1251 'ccl
+ "Coding-system used for Windows-1251."
+ '(decode ccl-decode-windows1251
+   encode ccl-encode-windows1251
+   mnemonic "CyrW"))
+
+;; `iso-8-1' is not correct, but XEmacs doesn't have a `ccl' category
+(coding-system-put 'windows-1251 'category 'iso-8-1)
+
+(set-language-info-alist
+ "Cyrillic-Win" '((charset cyrillic-iso8859-5)
+		   (coding-system windows-1251)
+		   (coding-priority windows-1251)
+		   (input-method . "cyrillic-yawerty")
+		   (features cyril-util)
+		   (tutorial . "TUTORIAL.ru")
+		   (sample-text . "Russian (,L@caaZXY(B)	,L7T`PRabRcYbU(B!")
+		   (documentation . "Support for Cyrillic Windows-1251."))
+ '("Cyrillic"))
+
+;;; ALTERNATIVNYJ
 
 (eval-and-compile
 
@@ -242,26 +300,16 @@
 	 (write-read-repeat r0 ,cyrillic-alternativnyj-encode-table))))))
   "CCL program to encode Alternativnyj.")
 
-;; (make-coding-system
-;;  'cyrillic-alternativnyj 4 ?A
-;;  "ALTERNATIVNYJ 8-bit encoding for Cyrillic"
-;;  '(ccl-decode-alternativnyj . ccl-encode-alternativnyj)
-;;  '((safe-charsets ascii cyrillic-iso8859-5)
-;;    (valid-codes (0 . 175) (224 . 241) 255)
-;;    (charset-origin-alist (cyrillic-iso8859-5 "ALTERNATIVNYJ"
-;;                                              cyrillic-encode-koi8-r-char))))
-
-
 ;; (define-coding-system-alias 'alternativnyj 'cyrillic-alternativnyj)
 
 (make-coding-system
  'alternativnyj 'ccl
  "Coding-system used for Alternativnyj"
- `(decode ,ccl-decode-alternativnyj
-   encode ,ccl-encode-alternativnyj
+ '(decode ccl-decode-alternativnyj
+   encode ccl-encode-alternativnyj
    mnemonic "Cy.Alt"))
 
-;; it is not correct, but XEmacs doesn't have `ccl' category...
+;; `iso-8-1' is not correct, but XEmacs doesn't have `ccl' category
 (coding-system-put 'alternativnyj 'category 'iso-8-1)
 
 ;; (define-ccl-program ccl-encode-alternativnyj-font
@@ -25,12 +25,13 @@
 ;;; Commentary:
 
-;; The character set ISO8859-5 is supported.  KOI-8 and ALTERNATIVNYJ
-;; are converted to ISO8859-5 internally.
+;; The character set ISO8859-5 is supported.
+;; KOI-8, Windows-1251, and ALTERNATIVNYJ are converted to ISO8859-5
+;; internally.
 
 ;;; Code: